[TODO: write documentation for this plugin.] { "name": "Unreliable Plugin", "type": "window", "tags": [], "ui": "", "version": "0.1.0", "api_version": "0.1.7", "description": "[TODO: describe this plugin with one sentence.]", "icon": "extension", "inputs": null, "outputs": null, "env": "", "requirements": [], "dependencies": [], "defaults": {"w": 7, "h": 7}, "readiness_probe": { "exec": "isReady", "initial_delay_seconds": 1, "period_seconds": 2, "success_threshold": 1, "failure_threshold": 2 }, "liveness_probe":{ "exec": "isAlive", "initial_delay_seconds": 1, "period_seconds": 2, "failure_threshold": 2 } }

Hello World